@@ -11,11 +11,11 @@ logger = logging.getLogger(__name__)
 
 class Csv(FileTypeFormat):
 
-    _fileType = "csv"
+    _filetype = "csv"
 
     _process_kwargs = ["databaseSynId"]
 
-    def _validateFilename(self, filePath):
+    def _validate_filetype(self, filePath):
         assert os.path.basename(filePath[0]).endswith(".csv")
 
     def _process(self, df):
@@ -33,5 +33,5 @@ class Csv(FileTypeFormat):
         total_error = ""
         warning = ""
         if df.empty:
-            total_error += "{}: File must not be empty".format(self._fileType)
+            total_error += "{}: File must not be empty".format(self._filetype)
         return total_error, warning
